@@ -15,11 +15,11 @@ Toader::Page - This provides methods for a named page.
 
 =head1 VERSION
 
-Version 0.0.1
+Version 0.0.2
 
 =cut
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 =head1 SYNOPSIS
 
@@ -58,6 +58,13 @@ This is the from address to use.
 
 This is a list of files that will be made available with this page.
 
+=head4 publish
+
+Wether or not to publish it or not. This is a boolean value and uses "0"
+and "1".
+
+If not specified, it uses "1".
+
     my $foo = Toader::isaToaderDir->new(\%args);
     if ($foo->error){
        warn('Error:'.$foo->error.': '.$foo->errorString);
@@ -107,6 +114,17 @@ sub new{
 		$args{publish}='1';
 	}
 
+	if (
+		( $args{publish} ne "0" ) &&
+		( $args{publish} ne "1" )
+		){
+		$self->{error}=13;
+		$self->{perror}=1;
+		$self->{errorString}='"'.$args{publish}.'" not a published boolean';
+		$self->warn;
+		return $self;
+	}
+
 	#this will hold the various parts
 	my @parts;
 	my $int=0;
@@ -282,6 +300,19 @@ sub newFromString{
 	if (!defined( $mime->header( "publish" ) )) {
 		$mime->header_set(publish=>'1');
 	}
+
+	#makes sure the publish value is good
+	if (
+		( $mime->header( "publish" ) ne "0" ) &&
+		( $mime->header( "publish" ) ne "1" )
+		){
+		$self->{perror}=1;
+		$self->{error}=13;
+		$self->{errorString}='"'.$mime->header( "publish" ).
+			'" is not a recognized boolean value';
+		$self->warn;
+		return $self;
+	}
 	
 	$self->{mime}=$mime;
 
@@ -583,7 +614,25 @@ sub publishGet{
 		return undef;
 	}
 
-	return $self->{mime}->header('publish');
+	my $publish=$self->{mime}->header('publish');
+
+	#if not defined, return the default
+	if ( ! defined( $publish ) ){
+		return '1';
+	}
+
+	#make sure it is a recognized boolean value
+	if (
+		( $publish ne '0' ) &&
+		( $publish ne '1' )
+		){
+		$self->{error}=13;
+		$self->{errorString}='Not a recognized boolean value';
+		$self->warn;
+		return undef;
+	}
+
+	return $publish;
 }
 
 =head2 publishSet
@@ -592,6 +641,10 @@ This sets the publish value.
 
 One argument is taken and it is the publish value.
 
+If no value is set, it uses the default, "1".
+
+It must be a recognized boolean value, either "0" or "1".
+
     $foo->publishSet($publish);
     if($foo->error){
         warn('error: '.$foo->error.":".$foo->errorString);
@@ -608,14 +661,14 @@ sub publishSet{
 	}
 
 	if (!defined( $publish )) {
-		$publish='0';
+		$publish='1';
 	}
 
 	if (
 		( $publish ne '0' ) &&
 		( $publish ne '1' )
 		){
-		$self->error=19;
+		$self->error=13;
 		$self->errorString='The publish value is not "0" or "1", but "'.$publish.'"';
 		$self->warn;
 		return undef;
@@ -1222,6 +1275,10 @@ No directory has been specified.
 
 The pages directory could not be created.
 
+=head2 13
+
+The publish value is not a recognized boolean value.
+
 =head1 AUTHOR
 
 Zane C. Bowers-Hadley, C<< <vvelox at vvelox.net> >>
